@@ -73,7 +73,6 @@ class CodeBuild(Base):
 
         paginator = self.client.get_paginator("list_projects")
         for page in paginator.paginate(**param):
-
             resp = self.client.batch_get_projects(names=page.get("projects", []))
             self.projects.extend(resp["projects"])
 
@@ -101,9 +100,13 @@ class CodeBuild(Base):
         param = {"projectName": self.project["name"], "sortOrder": "DESCENDING"}
         paginator = self.client.get_paginator("list_builds_for_project")
         for page in paginator.paginate(**param):
-
             left = max_builds - len(self.builds)
-            resp = self.client.batch_get_builds(ids=page.get("ids", [])[:left])
+            # print(page)
+            ids = page.get("ids", [])
+            if len(ids) == 0:
+                break
+
+            resp = self.client.batch_get_builds(ids=ids[:left])
             self.builds.extend(resp["builds"])
 
             if len(self.builds) >= max_builds:
@@ -197,9 +200,9 @@ class CodeBuild(Base):
             return
 
         env_var = env_vars[env_id - 1]
-        new_value = o7i.input_string(f'Enter new value for {env_var["name"]} -> ')
+        new_value = o7i.input_string(f"Enter new value for {env_var['name']} -> ")
 
-        if o7i.is_it_ok(f'Confirm that {env_var["name"]} -> {new_value}'):
+        if o7i.is_it_ok(f"Confirm that {env_var['name']} -> {new_value}"):
             self.update_env_variable(env_var["name"], new_value)
 
     # *************************************************
@@ -259,18 +262,16 @@ class CodeBuild(Base):
         self.load_builds()
 
         # General Information
-        print(f'Description: {self.project.get("description", "NA")}')
-        print(f'Created: {self.project.get("created", None):%Y-%m-%d %H:%M:%S}')
-        print(
-            f'Modified: { o7f.elapse_time(self.project.get("lastModified", None))} ago'
-        )
-        print(f'Tags: { self.project.get("tags", "None")}')
+        print(f"Description: {self.project.get('description', 'NA')}")
+        print(f"Created: {self.project.get('created', None):%Y-%m-%d %H:%M:%S}")
+        print(f"Modified: {o7f.elapse_time(self.project.get('lastModified', None))} ago")
+        print(f"Tags: {self.project.get('tags', 'None')}")
 
         print("")
         env = self.project.get("environment", {})
-        print(f'Type: {env.get("type", "")}')
-        print(f'Compute Type: {env.get("computeType", "")}')
-        print(f'Image: {env.get("image", "")}')
+        print(f"Type: {env.get('type', '')}")
+        print(f"Compute Type: {env.get('computeType', '')}")
+        print(f"Image: {env.get('image', '')}")
 
         # Env Var
         print("Environment Variables")
@@ -284,7 +285,7 @@ class CodeBuild(Base):
         )
         Table(envvar_params, env.get("environmentVariables", [])).print()
         print("")
-        print(f'Service Role: {self.project.get("serviceRole", "")}')
+        print(f"Service Role: {self.project.get('serviceRole', '')}")
         print("")
         print(f"Last {len(self.builds)} builds")
         # Env Var
@@ -313,14 +314,14 @@ class CodeBuild(Base):
         self.refresh_build_details()
 
         # General Information
-        print(f'Project Name: {self.build.get("projectName", "NA")}')
-        print(f'Start Time: {self.build.get("startTime", None):%Y-%m-%d %H:%M:%S}')
-        print(f'Duration: {o7f.elapse_time(self.build.get("diffTime", None))}')
-        print(f'Status: { o7t.format_aws_status(self.build.get("buildStatus", "NA"))}')
-        print(f'Artifacts: {self.build.get("artifacts", {}).get("location", "")}')
+        print(f"Project Name: {self.build.get('projectName', 'NA')}")
+        print(f"Start Time: {self.build.get('startTime', None):%Y-%m-%d %H:%M:%S}")
+        print(f"Duration: {o7f.elapse_time(self.build.get('diffTime', None))}")
+        print(f"Status: {o7t.format_aws_status(self.build.get('buildStatus', 'NA'))}")
+        print(f"Artifacts: {self.build.get('artifacts', {}).get('location', '')}")
         print("")
         env = self.build.get("environment", {})
-        print(f'Type: {env.get("type", "")}   Compute: {env.get("computeType", "") }')
+        print(f"Type: {env.get('type', '')}   Compute: {env.get('computeType', '')}")
 
         # Env Var
         envvar_params = TableParam(
@@ -522,7 +523,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     logging.basicConfig(
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
