@@ -16,9 +16,7 @@
 # ************************************************************************
 """Module allows to view and access EC2 Instances"""
 
-# --------------------------------
-#
-# --------------------------------
+import datetime
 import logging
 import pprint
 import subprocess
@@ -28,6 +26,7 @@ import o7util.menu as o7m
 import o7util.terminal as o7t
 from o7util.table import ColumnParam, Table, TableParam
 
+import o7cli.ssm as o7ssm
 from o7cli.base import Base
 
 logger = logging.getLogger(__name__)
@@ -182,33 +181,37 @@ class Ec2(Base):
 
         print("")
 
-        print(f'Instance Id: {self.instance.get("InstanceId", "")}')
-        print(f'Type: {self.instance.get("InstanceType", "")}')
-        print(f'Launch: {self.instance.get("LaunchTime", "")}')
-        print(f'Private IP: {self.instance.get("PrivateIpAddress", "")}')
-        print(f'Public IP: {self.instance.get("PublicIpAddress", "")}')
-        print(f'V6 IP: {self.instance.get("Ipv6Address", "")}')
+        print(f"Instance Id: {self.instance.get('InstanceId', '')}")
+        print(f"Type: {self.instance.get('InstanceType', '')}")
+        print(f"Launch: {self.instance.get('LaunchTime', '')}")
+        print(f"Private IP: {self.instance.get('PrivateIpAddress', '')}")
+        print(f"Public IP: {self.instance.get('PublicIpAddress', '')}")
+        print(f"V6 IP: {self.instance.get('Ipv6Address', '')}")
 
         print()
-        print(f'State: {o7t.format_aws_state(self.instance["State"]["Name"])}')
-        print(f'State Reason: {self.instance.get("StateReason", "-")}')
+        print(f"State: {o7t.format_aws_state(self.instance['State']['Name'])}")
+        print(f"State Reason: {self.instance.get('StateReason', '-')}")
         print(
-            f'Instance Status: {self.instance_status.get("InstanceStatus",{}).get("Status","na")}'
+            f"Instance Status: {self.instance_status.get('InstanceStatus', {}).get('Status', 'na')}"
         )
         print(
-            f'System Status: {self.instance_status.get("SystemStatus",{}).get("Status","na")}'
+            f"System Status: {self.instance_status.get('SystemStatus', {}).get('Status', 'na')}"
         )
         print()
 
         print(
-            f'Metadate Endpoint: {self.instance.get("MetadataOptions",{}).get("HttpEndpoint","-")}'
+            f"Metadate Endpoint: {self.instance.get('MetadataOptions', {}).get('HttpEndpoint', '-')}"
         )
-        print(f'IMDSv2: {self.instance.get("MetadataOptions",{}).get("HttpTokens","-")}')
         print(
-            f'Allow Tags Metadata: {self.instance.get("MetadataOptions",{}).get("InstanceMetadataTags","-")}'
+            f"IMDSv2: {self.instance.get('MetadataOptions', {}).get('HttpTokens', '-')}"
+        )
+        print(
+            f"Allow Tags Metadata: {self.instance.get('MetadataOptions', {}).get('InstanceMetadataTags', '-')}"
         )
         print()
 
+        tags = sorted(self.instance.get("Tags", []), key=lambda x: x["Key"].upper())
+
         Table(
             TableParam(
                 title="Tags",
@@ -217,7 +220,7 @@ class Ec2(Base):
                     ColumnParam(title="Value", type="str", data_col="Value"),
                 ],
             ),
-            self.instance.get("Tags", []),
+            tags,
         ).print()
         print()
 
@@ -277,28 +280,40 @@ class Ec2(Base):
     # *************************************************
     #
     # *************************************************
-    def start_forward_rdp(self):
+    # def start_forward_rdp(self):
+    #     """Start port forwarding for RDP"""
+
+    #     instance_id = self.instance.get("InstanceId", "na")
+
+    #     cmds = [
+    #         "aws",
+    #         "--region",
+    #         self.session.region_name,
+    #         "ssm",
+    #         "start-session",
+    #         "--target",
+    #         instance_id,
+    #         "--document-name",
+    #         "AWS-StartPortForwardingSession",
+    #         "--parameters",
+    #         "localPortNumber=54321,portNumber=3389",
+    #     ]
+
+    #     print(f"CommandS: {cmds}")
+    #     print("Connect local RDP to localhost:54321")
+    #     subprocess.call(cmds, shell=False)  # noqa: S603
+
+    # *************************************************
+    #
+    # *************************************************
+    def start_auto_rdp(self):
         """Start port forwarding for RDP"""
 
         instance_id = self.instance.get("InstanceId", "na")
+        logger.info(f"Starting RDP session with {instance_id}")
 
-        cmds = [
-            "aws",
-            "--region",
-            self.session.region_name,
-            "ssm",
-            "start-session",
-            "--target",
-            instance_id,
-            "--document-name",
-            "AWS-StartPortForwardingSession",
-            "--parameters",
-            "localPortNumber=54321,portNumber=3389",
-        ]
-
-        print(f"CommandS: {cmds}")
-        print("Connect local RDP to localhost:54321")
-        subprocess.call(cmds, shell=False)  # noqa: S603
+        o7ssm_obj = o7ssm.Ssm(session=self.session)
+        o7ssm_obj.open_rdp_session(instance_id=instance_id)
 
     # *************************************************
     #
@@ -342,7 +357,7 @@ class Ec2(Base):
 
         obj = o7m.Menu(
             exit_option="b",
-            title=f'EC2 Instance - {self.instance.get("InstanceId","na")}',
+            title=f"EC2 Instance - {self.instance.get('InstanceId', 'na')}",
             title_extra=self.session_info(),
             compact=False,
         )
@@ -385,12 +400,17 @@ class Ec2(Base):
                 callback=self.start_session_shell,
             )
         )
-        obj.add_option(
-            o7m.Option(key="rdp", name="RDP Forwarding", callback=self.start_forward_rdp)
-        )
+        # obj.add_option(
+        #     o7m.Option(key="rdp", name="Open RDP Session", callback=self.start_auto_rdp)
+        # )
         obj.add_option(
             o7m.Option(key="pf", name="Port Forwarding", callback=self.start_forward_port)
         )
+        obj.add_option(
+            o7m.Option(
+                key="m", name="Get Instance Metrics", callback=self.get_instance_metrics
+            )
+        )
 
         obj.display_callback = self.display_instance
         obj.loop()
@@ -430,6 +450,99 @@ class Ec2(Base):
 
         return self
 
+    # *************************************************
+    #
+    # *************************************************
+    def get_instance_metrics(self, instance_id=None):
+        """Get average CPU utilization for the last 5 minutes, 1 hour, and 1 day"""
+
+        if instance_id is None:
+            instance_id = self.instance.get("InstanceId", "na")
+
+        cloudwatch = self.session.client("cloudwatch")
+        now = datetime.datetime.now(datetime.UTC)
+        periods = {
+            "5min": (now - datetime.timedelta(minutes=5), 300),
+            "1h": (now - datetime.timedelta(hours=1), 3600),
+            "1d": (now - datetime.timedelta(days=1), 86400),
+        }
+
+        metrics = [
+            "CPUUtilization",
+            "CPUCreditBalance",
+            "CPUSurplusCreditsCharged",
+            "EBSWriteBytes",
+            "EBSReadBytes",
+            "EBSReadOps",
+            "EBSWriteOps",
+            "NetworkIn",
+            "NetworkOut",
+            "NetworkPacketsIn",
+            "NetworkPacketsOut",
+        ]
+
+        metrics = {
+            "CPUUtilization": "Average",
+            "CPUCreditBalance": "Average",
+            "CPUSurplusCreditsCharged": "Sum",
+            "EBSWriteBytes": "Average",
+            "EBSReadBytes": "Average",
+            "EBSReadOps": "Average",
+            "EBSWriteOps": "Average",
+            "NetworkIn": "Average",
+            "NetworkOut": "Average",
+            "NetworkPacketsIn": "Average",
+            "NetworkPacketsOut": "Average",
+            "StatusCheckFailed": "Sum",
+        }
+
+        results = []
+        for metric, statistic in metrics.items():
+            result = {"Metric": metric, "Statistic": statistic}
+            for label, (start, period) in periods.items():
+                response = cloudwatch.get_metric_statistics(
+                    Namespace="AWS/EC2",
+                    MetricName=metric,
+                    Dimensions=[{"Name": "InstanceId", "Value": instance_id}],
+                    StartTime=start,
+                    EndTime=now,
+                    Period=period,
+                    Statistics=[statistic],
+                )
+                datapoints = response.get("Datapoints", [])
+                value = None
+                unit = "na"
+
+                if datapoints:
+                    # Get the latest datapoint
+                    datapoint = sorted(
+                        datapoints, key=lambda x: x["Timestamp"], reverse=True
+                    )[0]
+                    value = datapoint[statistic]
+                    unit = datapoint.get("Unit", "na")
+
+                # print(f"Average {metric} for {label}: {avg} {unit}")
+                result[label] = value
+                result["Unit"] = unit
+
+            results.append(result)
+
+        Table(
+            TableParam(
+                title="Instance Statistics",
+                columns=[
+                    ColumnParam(title="Metric", type="str", data_col="Metric"),
+                    ColumnParam(title="Statistic", type="str", data_col="Statistic"),
+                    ColumnParam(title="1-Day", type="int", data_col="1d"),
+                    ColumnParam(title="1-Hour", type="int", data_col="1h"),
+                    ColumnParam(title="5-Min", type="int", data_col="5min"),
+                    ColumnParam(title="Unit", type="str", data_col="Unit"),
+                ],
+            ),
+            results,
+        ).print()
+        return results
+
 
 # *************************************************
 #
@@ -447,7 +560,10 @@ if __name__ == "__main__":
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
 
-    ec2_obj = Ec2().menu_instances()
+    # ec2_obj = Ec2().menu_instances()
+
+    Ec2().get_instance_metrics("i-0bc09a0ba8e419a5d")
+
     # ec2_obj = Ec2().load_instance('i-01ba040ef1b4671da')
     # pprint.pprint(ec2_obj.instance_status)
     # Ec2().MenuInstances()
