@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 # ************************************************************************
-""" Module for AWS Eventbridge"""
+"""Module for AWS Eventbridge"""
 
 # --------------------------------
 #
@@ -43,7 +43,6 @@ class Eventbridge(Base):
     #
     # *************************************************
     def __init__(self, **kwargs):
-
         super().__init__(**kwargs)
         self.cwe = self.session.client("events")
 
@@ -75,7 +74,7 @@ class Eventbridge(Base):
         if gd_rule.iloc[0]["State"] == "ENABLED":
             report.test_pass()
         else:
-            report.test_fail(f'State is {gd_rule.iloc[0]["State"] }')
+            report.test_fail(f"State is {gd_rule.iloc[0]['State']}")
 
         # Check for SNS Target
         report.add_test(name=f"{name} Event Rule has an SNS Target", critical=True)
@@ -137,16 +136,13 @@ class Eventbridge(Base):
         for page in paginator.paginate(**param):
             rules.extend(page.get("Rules", []))
 
-        return pd.DataFrame(
-            data=rules, columns=["Name", "EventPattern", "Arn", "State"]
-        )
+        return pd.DataFrame(data=rules, columns=["Name", "EventPattern", "Arn", "State"])
 
 
 # *************************************************
 #
 # *************************************************
 if __name__ == "__main__":
-
     pd.set_option("display.max_rows", None)
     pd.set_option("display.max_columns", None)
     pd.set_option("display.width", -1)
@@ -158,9 +154,7 @@ if __name__ == "__main__":
     the_rules = Eventbridge().load_rules()
     pprint.pprint(the_rules[["Name", "State"]])
 
-    the_targets = Eventbridge().load_targets(
-        rule_name="Automated-GuardDuty-Notification"
-    )
+    the_targets = Eventbridge().load_targets(rule_name="Automated-GuardDuty-Notification")
     pprint.pprint(the_targets.iloc[0])
 
     # pprint.pprint(rules[rules['EventPattern'] == '{"source":["aws.guardduty"]}'])
