@@ -54,10 +54,11 @@ class S3(Base):
 
         self.client = self.session.client("s3")
 
-        self.buckets: list = []
+        self.buckets: list = None
 
         self.bucket: str = ""
         self.with_buckets_details: bool = False
+        self.with_buckets_size: bool = False
         self.prefix: str = ""
         self.key: str = ""
 
@@ -208,7 +209,7 @@ class S3(Base):
         try:
             response = self.client.get_bucket_versioning(Bucket=bucket)
         except self.client.exceptions.from_code("NoSuchBucketPolicy"):
-            return []
+            return {}
 
         return {
             "Status": response.get("Status", "Disabled"),
@@ -234,7 +235,7 @@ class S3(Base):
     #
     # *************************************************
     def get_bucket_metrics(self, bucket: str = None):
-        """Get average CPU utilization for the last 5 minutes, 1 hour, and 1 day"""
+        """Get statistics on bucket sizefor a bucket"""
 
         if bucket is None:
             bucket = self.bucket
@@ -329,6 +330,38 @@ class S3(Base):
         ).print()
         return results
 
+    # *************************************************
+    #
+    # *************************************************
+    def get_bucket_size(self, bucket: str = None):
+        """Get the size of a bucket"""
+
+        cloudwatch = self.session.client("cloudwatch")
+        stop = datetime.datetime.now(datetime.UTC)
+        start = stop - datetime.timedelta(days=1)
+
+        response = cloudwatch.get_metric_statistics(
+            Namespace="AWS/S3",
+            MetricName="BucketSizeBytes",
+            Dimensions=[
+                {"Name": "BucketName", "Value": bucket},
+                {"Name": "StorageType", "Value": "StandardStorage"},
+            ],
+            StartTime=start,
+            EndTime=stop,
+            Period=86400,
+            Statistics=["Average"],
+        )
+
+        ret = None
+        datapoints = response.get("Datapoints", [])
+        if datapoints:
+            ret = sorted(datapoints, key=lambda x: x["Timestamp"], reverse=False)[0].get(
+                "Average", None
+            )
+
+        return ret
+
     # *************************************************
     #
     # *************************************************
@@ -357,16 +390,21 @@ class S3(Base):
 
         logger.info("load_buckets")
 
-        # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.list_buckets
-        resp = self.client.list_buckets()
-        # pprint.pprint(resp)
-
-        self.buckets = resp.get("Buckets", [])
-        logger.info(f"LoadBuckets: Number of Bucket found: {len(self.buckets)}")
+        if self.buckets is None:
+            # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.list_buckets
+            resp = self.client.list_buckets()
+            self.buckets = resp.get("Buckets", [])
+            logger.info(f"LoadBuckets: Number of Bucket found: {len(self.buckets)}")
 
         if self.with_buckets_details:
             for bucket in self.buckets:
                 bucket.update(self.get_bucket_details(bucket=bucket["Name"]))
+            self.with_buckets_details = False
+
+        if self.with_buckets_size:
+            for bucket in self.buckets:
+                bucket["Size"] = self.get_bucket_size(bucket=bucket["Name"])
+            self.with_buckets_size = False
 
         return self
 
@@ -378,6 +416,14 @@ class S3(Base):
         self.with_buckets_details = True
         return self
 
+    # *************************************************
+    #
+    # *************************************************
+    def load_buckets_size(self):
+        """Load size for all buckets"""
+        self.with_buckets_size = True
+        return self
+
     # *************************************************
     #
     # *************************************************
@@ -562,6 +608,12 @@ class S3(Base):
                     data_col="ObjectLock",
                     normal="Enabled",
                 ),
+                ColumnParam(
+                    title="Size",
+                    type="bytes",
+                    data_col="Size",
+                    # footer="sum",
+                ),
             ]
         )
 
@@ -766,6 +818,15 @@ class S3(Base):
                 callback=self.load_buckets_extra,
             )
         )
+        obj.add_option(
+            o7m.Option(
+                key="s",
+                name="Load Size",
+                short="Load Size",
+                wait=False,
+                callback=self.load_buckets_size,
+            )
+        )
 
         obj.add_option(
             o7m.Option(
