@@ -69,12 +69,15 @@ class SecurityHub(Base):
         super().__init__(**kwargs)
         self.client = self.session.client("securityhub")
 
+        self.client_us_east_1 = self.session.client(
+            "securityhub", region_name="us-east-1"
+        )
+
         # From AWS loading & calculation
         self.df_standards: pd.DataFrame = None
         self.df_standards_results: pd.DataFrame = None
         # self.df_standards_global : pd.DataFrame = None
         self.df_controls: pd.DataFrame = None
-        self.df_ctrl_def: pd.DataFrame = None
         self.df_controls_results: pd.DataFrame = None
         self.df_findings: pd.DataFrame = None
 
@@ -217,17 +220,17 @@ class SecurityHub(Base):
 
         for standards, row in df_ready.iterrows():
             controls = []
-            definitions = []
 
-            #
             # print(f'Loading controls for {standards} = {row["StandardsSubscriptionArn"]}')
             # print(row)
 
             # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securityhub/client/describe_standards_controls.html
-            paginator = self.client.get_paginator("describe_standards_controls")
+            paginator = self.client_us_east_1.get_paginator("describe_standards_controls")
 
             for page in paginator.paginate(
-                StandardsSubscriptionArn=row["StandardsSubscriptionArn"],
+                StandardsSubscriptionArn=row["StandardsSubscriptionArn"].replace(
+                    "ca-central-1", "us-east-1"
+                ),
             ):
                 controls.extend(page.get("Controls", []))
 
@@ -242,47 +245,20 @@ class SecurityHub(Base):
                     [self.df_controls, df_controls], ignore_index=True
                 )
 
-            # https://boto3.amazonaws.com/v1/documentation/api/1.26.88/reference/services/securityhub/client/list_security_control_definitions.html
-            paginator = self.client.get_paginator("list_security_control_definitions")
-
-            for page in paginator.paginate(
-                StandardsArn=row["StandardsArn"],
-            ):
-                definitions.extend(page.get("SecurityControlDefinitions", []))
-
-            # print(f'Number of controls found {len(controls)}')
-            df_definitions = pd.DataFrame(definitions)
-            df_definitions["Standards"] = standards
-
-            if self.df_ctrl_def is None:
-                self.df_ctrl_def = df_definitions
-            else:
-                self.df_ctrl_def = pd.concat(
-                    [self.df_ctrl_def, df_definitions], ignore_index=True
-                )
-
         self.df_controls["ControlStatusUpdatedAt"] = self.df_controls[
             "ControlStatusUpdatedAt"
         ].dt.tz_localize(None)
         self.df_controls["StandardsControl"] = (
             self.df_controls["StandardsControlArn"].str.split(":").str[-1]
         )
+        self.df_controls["RelatedRequirement"] = self.df_controls["RelatedRequirements"]
+        self.df_controls = self.df_controls.explode("RelatedRequirement")
         self.df_controls["IsDisabled"] = self.df_controls["ControlStatus"] == "DISABLED"
 
         gb = self.df_controls.groupby(["Standards"])
         self.df_standards["ControlsCount"] = gb["ControlId"].count()
         self.df_standards["ControlsDisabled"] = gb["IsDisabled"].sum()
 
-        self.df_ctrl_def["StandardsControl"] = self.df_ctrl_def["Standards"].str.replace(
-            "standards", "control"
-        )
-        self.df_ctrl_def["StandardsControl"] = (
-            self.df_ctrl_def["StandardsControl"]
-            + "/"
-            + self.df_ctrl_def["SecurityControlId"]
-        )
-        self.df_ctrl_def["ControlId"] = self.df_ctrl_def["SecurityControlId"]
-
     # *************************************************
     #
     # *************************************************
@@ -334,6 +310,12 @@ class SecurityHub(Base):
 
         df = pd.DataFrame(findings)
 
+        # Extract fields for the Related Requirement & explode
+        df["RelatedRequirement"] = df["Compliance"].apply(
+            lambda x: x.get("RelatedRequirements", [""]) if isinstance(x, dict) else [""]
+        )
+        df = df.explode("RelatedRequirement")
+
         df["StandardsArn"] = df["ProductFields"].apply(
             lambda x: x.get("StandardsArn", x.get("StandardsGuideArn", None))
         )
@@ -553,37 +535,32 @@ class SecurityHub(Base):
         df_accounts = pd.DataFrame({"AwsAccountId": df["AwsAccountId"].unique()})
 
         # Compile Controls stattus with Findings
-        gb_std_ctrl = df.groupby(["Standards", "AwsAccountId", "StandardsControl"])
+        gb_std_ctrl = df.groupby(["Standards", "AwsAccountId", "RelatedRequirement"])
 
         df_std_ctrl = pd.DataFrame(
             index=gb_std_ctrl.groups.keys(),
         )
-        df_std_ctrl.index.names = ["Standards", "AwsAccountId", "StandardsControl"]
+        df_std_ctrl.index.names = ["Standards", "AwsAccountId", "RelatedRequirement"]
         df_std_ctrl["AccountName"] = gb_std_ctrl["AccountName"].first()
         df_std_ctrl["CheckCount"] = gb_std_ctrl["passed"].count()
         df_std_ctrl["CheckPass"] = gb_std_ctrl["passed"].sum()
         df_std_ctrl["CheckFail"] = df_std_ctrl["CheckCount"] - df_std_ctrl["CheckPass"]
 
         # Create list of all Controls for all accounts
-        df_controls = self.df_ctrl_def[
+        df_controls = self.df_controls[
             [
                 "Standards",
-                "StandardsControl",
+                "RelatedRequirement",
                 "ControlId",
                 "SeverityRating",
+                "IsDisabled",
             ]
         ].copy()
-        # Get the disabled controls flag
-        df_controls = df_controls.merge(
-            self.df_controls[["StandardsControl", "IsDisabled"]],
-            how="left",
-            on="StandardsControl",
-        )
 
         df_accounts["key"] = 1
         df_controls["key"] = 1
         df = pd.merge(left=df_accounts, right=df_controls, on="key").drop("key", axis=1)
-        df.set_index(["Standards", "AwsAccountId", "StandardsControl"], inplace=True)
+        df.set_index(["Standards", "AwsAccountId", "RelatedRequirement"], inplace=True)
 
         # Merge with Findings results
         df = df.merge(df_std_ctrl, how="outer", left_index=True, right_index=True)
@@ -672,7 +649,7 @@ class SecurityHub(Base):
 
         # self.df_standards_global = df_std
 
-        # print(self.df_standards_global)
+        # print(self.df_standards_results)
         # o7i.is_it_ok('Press Enter to continue')
 
         return self
@@ -1166,7 +1143,7 @@ class SecurityHub(Base):
 
         dfs = {
             "standards": self.df_standards,
-            "controls": self.df_ctrl_def,
+            "controls": self.df_controls,
             "findings": self.df_findings,
             "standards_results": self.df_standards_results,
             "controls_results": self.df_controls_results,
@@ -1508,7 +1485,6 @@ class SecurityHub(Base):
 
             self.df_standards.to_excel(writer, sheet_name="Standards")
             self.df_controls.to_excel(writer, sheet_name="Controls")
-            self.df_ctrl_def.to_excel(writer, sheet_name="ControlsDef")
 
             for col in self.df_accounts:
                 if pd.api.types.is_datetime64tz_dtype(self.df_accounts[col]):
@@ -2347,7 +2323,7 @@ if __name__ == "__main__":
 
     exit(0)
 
-    the_report = the_obj.generate_html_report()
+    # the_report = the_obj.generate_html_report()
 
     # print('*'*80)
     # print(the_report)
@@ -2358,10 +2334,10 @@ if __name__ == "__main__":
     # --------------------------------
     # Save to File
     # --------------------------------
-    filname = "security_hub.cache.html"
-    try:
-        with open(filname, "w", newline="", encoding="utf-8") as htmlfile:
-            htmlfile.write(the_report)
+    # filname = "security_hub.cache.html"
+    # try:
+    #     with open(filname, "w", newline="", encoding="utf-8") as htmlfile:
+    #         htmlfile.write(the_report)
 
-    except IOError:
-        print(f"Count not write to: {filname}")
+    # except IOError:
+    #     print(f"Count not write to: {filname}")
